# Pacote para ter acesso a funcoes de tratamento e extracao de dados RDS
* Aqui se localiza a biblioteca etl e o serviço de etl do RDS
* Joguei ele para um pacote para facilidade de importação e aproveitamento de classes de limpeza
## Como instalar a biblioteca?
* pip install etl-csm==0.0.1
* Pronto
# Configuração de ambiente?
* O ambiente e suas demandas localizam-se na environment.yml repassada
